pub enum PackagedArtifactTargetThresholdScopeEnvelopesSummaryValidationError {
FieldOutOfSync {
field: &'static str,
},
}Expand description
Validation error for a packaged-artifact target-threshold scope envelopes summary that drifted from the current posture.
Variants
FieldOutOfSync
A summary field is out of sync with the current packaged-artifact posture.