pub struct PackagedArtifactStorageSummary;Expand description
Structured storage/reconstruction summary for the packaged artifact.
Implementations
Sourceimpl PackagedArtifactStorageSummary
impl PackagedArtifactStorageSummary
Sourcepub const fn summary_line(self) -> &'static str
pub const fn summary_line(self) -> &'static str
Returns the storage and reconstruction posture as a compact human-readable line.
Sourcepub fn validate(
&self,
) -> Result<(), PackagedArtifactStorageSummaryValidationError>
pub fn validate( &self, ) -> Result<(), PackagedArtifactStorageSummaryValidationError>
Returns Ok(()) when the summary still contains a compact canonical line.