pub struct PackagedArtifactTargetThresholdScopeSummary {
pub scope: &'static str,
pub bodies: Vec<CelestialBody>,
pub body_count: usize,
pub fit_envelope: PackagedArtifactFitEnvelopeSummary,
}Fields
scope: &'static strRelease-scoped body class that the fit envelope applies to.
bodies: Vec<CelestialBody>Bundled bodies that contribute to the scope envelope.
body_count: usizeBundled bodies that contribute to the scope envelope.
fit_envelope: PackagedArtifactFitEnvelopeSummaryMeasured fit envelope for the scoped body set.
Implementations
Sourceimpl PackagedArtifactTargetThresholdScopeSummary
impl PackagedArtifactTargetThresholdScopeSummary
Sourcepub fn summary_line(&self) -> String
pub fn summary_line(&self) -> String
Returns the scope-specific fit posture as a compact human-readable line.
Sourcepub fn validated_summary_line(
&self,
) -> Result<String, PackagedArtifactFitEnvelopeSummaryValidationError>
pub fn validated_summary_line( &self, ) -> Result<String, PackagedArtifactFitEnvelopeSummaryValidationError>
Returns the validated scope-specific fit posture as a compact human-readable line.
Sourcepub fn validate(
&self,
) -> Result<(), PackagedArtifactFitEnvelopeSummaryValidationError>
pub fn validate( &self, ) -> Result<(), PackagedArtifactFitEnvelopeSummaryValidationError>
Returns Ok(()) when the scope summary still matches the current packaged-artifact posture.